@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from plone import api
+from plone.app.upgrade.utils import installOrReinstallProduct
 
 default_profile = "profile-rer.solrpush:default"
 
@@ -13,6 +14,10 @@ def update_registry(context):
     update_profile(context=context, name="plone.app.registry")
 
 
+def update_controlpanel(context):
+    update_profile(context=context, name="controlpanel")
+
+
 def to_1100(context):
     setup_tool = api.portal.get_tool(name="portal_setup")
     setup_tool.runAllImportStepsFromProfile("profile-rer.solrpush:to_1100")
@@ -29,3 +34,11 @@ def to_1200(context):
 def to_1300(context):
     setup_tool = api.portal.get_tool(name="portal_setup")
     setup_tool.runAllImportStepsFromProfile("profile-rer.solrpush:to_1300")
+
+
+def to_1400(context):
+    installOrReinstallProduct(
+        api.portal.get(), "collective.z3cform.jsonwidget"
+    )
+    update_registry(context)
+    update_controlpanel(context)
